<?php

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Controller\Admin;

class Logs extends \XLite\Controller\Admin\AAdmin
{
    public function getTitle()
    {
        return static::t('System logs');
    }
}
